@@ -13,10 +13,10 @@ use Encode;
 use Scalar::Util qw( blessed );
 use HTML::TokeParser::Simple;
 use XML::Normalize::LibXML qw( xml_normalize );
-
+use LWP::Simple ();
 use overload q{""} => sub { +shift->as_string }, fallback => 1;
 
-our $VERSION = "0.99_04";
+our $VERSION = "0.99_05";
 our $AUTHORITY = 'cpan:ASHLEY';
 our $TITLE_ATTR = join("/", __PACKAGE__, $VERSION);
 
@@ -56,12 +56,19 @@ sub new {
     if ( ref($arg) eq "SCALAR" )
     {
         $self->_parse( $$arg );
-        # $self->_original_string( $$arg );
     }
     elsif ( blessed($arg) eq "Path::Class::File" )
     {
         $self->_parse( scalar $arg->slurp );
     }
+    elsif ( blessed($arg) eq __PACKAGE__ )
+    {
+        $self->_parse( $arg->as_string ); # Cloning.
+    }
+    elsif ( blessed($arg) =~ /\AURI::https?/ )
+    {
+        $self->_parse( LWP::Simple::get($arg) );
+    }
     elsif ( blessed($arg) and $arg->can("getlines") )
     {
         $self->_parse( join("", $arg->getlines) );
@@ -157,6 +164,10 @@ sub doc {
     +shift->{_doc};
 }
 
+sub text {
+    +shift->doc->getDocumentElement->textContent;
+}
+
 sub parser {
     my $self = shift;
     return $self->{_parser} if $self->{_parser};
@@ -526,6 +537,12 @@ sub same_same {
     $one eq $two or die "$one\n\n$two"
 }
 
+sub clone {
+    my $self = shift;
+    my $class = blessed($self);
+    $class->new($self);
+}
+
 1;
 
 __END__
@@ -536,7 +553,7 @@ XHTML::Util - (alpha software) powerful utilities for common but difficult to na
 
 =head2 VERSION
 
-0.99_04
+0.99_05
 
 =head1 SYNOPSIS
 
@@ -717,6 +734,10 @@ The L<XML::LibXML::Document> object created from input.
 
 The documentElement of the L<XML::LibXML::Document> object.
 
+=head2 text
+
+The C<textContent> of the root node.
+
 =head2 head
 
 The head element.
@@ -747,6 +768,8 @@ Returns true if the originally parsed item was a full HTML document.
 
 Returns true if the originally parsed item was a fragment.
 
+=head2 clone
+
 =head2 same_same
 
 Takes another XHTML::Util object or the valid argument to create one. Attempts to determine if the resulting object is the same as the calling object. E.g.,
@@ -789,6 +812,10 @@ L<XML::LibXML>, L<HTML::Tagset>, L<HTML::Entities>, L<HTML::Selector::XPath>, L<
 
 CSS W3Schools, L<http://www.w3schools.com/Css/default.asp>, Learning CSS at W3C, L<http://www.w3.org/Style/CSS/learning>.
 
+=head1 REPOSITORY
+
+git://github.com/pangyre/p5-xhtml-util
+
 =head1 AUTHOR
 
 Ashley Pond V, ashley at cpan.org.
